@@ -1,12 +1,12 @@
-#' Get Prior Definitions of a Dynamite Model
+#' Get Prior Definitions of a \pkg{dynamite} Model
 #'
-#' Extracts the priors used in the dynamite model as a data frame. You
+#' Extracts the priors used in the `dynamite` model as a data frame. You
 #' can then alter the priors by changing the contents of the `prior` column and
 #' supplying this data frame to `dynamite` function using the argument
 #' `priors`. See vignettes for details.
 #'
 #' @note Only the `prior` column of the output should be altered when defining
-#' the user-defined priors for the `dynamite`.
+#' the user-defined priors for `dynamite`.
 #'
 #' @export
 #' @family fitting
@@ -48,7 +48,7 @@ get_priors.dynamitefit <- function(x, ...) {
   x$priors
 }
 
-#' Extract the Stan Code of the Dynamite Model
+#' Extract the Stan Code of the \pkg{dynamite} Model
 #'
 #' Returns the Stan code of the model. Mostly useful for debugging or for
 #' building a customized version of the model.
@@ -105,7 +105,7 @@ get_code.dynamitefit <- function(x, blocks = NULL, ...) {
       ...
     )$model_code
   } else {
-    out <- x$stanfit@stanmodel@model_code[1L]
+    out <- get_model_code(x$stanfit)
   }
   get_code_(out, blocks)
 }
@@ -156,7 +156,7 @@ get_code_ <- function(x, blocks = NULL) {
   paste_rows(out, .parse = FALSE)
 }
 
-#' Extract the Model Data of the Dynamite Model
+#' Extract the Model Data of the \pkg{dynamite} Model
 #'
 #' Returns the input data to the Stan model. Mostly useful for debugging.
 #'
@@ -193,6 +193,9 @@ get_data.dynamiteformula <- function(x, data, time, group = NULL, ...) {
 #' @rdname get_data
 #' @export
 get_data.dynamitefit <- function(x, ...) {
+  if (!is.null(x$stan_input)) {
+    return(x$stan_input$sampling_vars)
+  }
   out <- dynamite(
     dformula = eval(formula(x)),
     data = x$data,
@@ -206,11 +209,11 @@ get_data.dynamitefit <- function(x, ...) {
   out$stan_input$sampling_vars
 }
 
-#' Get Parameter Dimensions of the Dynamite Model
+#' Get Parameter Dimensions of the \pkg{dynamite} Model
 #'
 #' Extracts the names and dimensions of all parameters used in the
-#' `dynamite` model. See also [dynamite::get_parameter_types()] and
-#' [dynamite::get_parameter_names()]. The returned dimensions match those of
+#' `dynamite` model. See also [get_parameter_types()] and
+#' [get_parameter_names()]. The returned dimensions match those of
 #' the `stanfit` element of the `dynamitefit` object. When applied to
 #' `dynamiteformula` objects, the model is compiled and sampled for 1 iteration
 #' to get the parameter dimensions.
@@ -232,52 +235,56 @@ get_parameter_dims <- function(x, ...) {
 #' @export
 get_parameter_dims.dynamiteformula <- function(x, data, time,
                                                group = NULL, ...) {
-  out <- try(
-    suppressWarnings(
-      dynamite(
-        dformula = x,
-        data = data,
-        time = time,
-        group = group,
-        algorithm = "Fixed_param",
-        chains = 1,
-        iter = 1,
-        refresh = 0,
-        backend = "rstan",
-        verbose_stan = FALSE,
-        ...
-      )
-    ),
-    silent = TRUE
+  out <- dynamite(
+    dformula = x,
+    data = data,
+    time = time,
+    group = group,
+    debug = list(no_compile = TRUE, stan_input = TRUE, model_code = FALSE),
+    ...
   )
-  stopifnot_(
-    !inherits(out, "try-error"),
-    c(
-      "Unable to determine parameter dimensions:",
-      `x` = attr(out, "condition")$message
-    )
-  )
-  get_parameter_dims(out)
+  get_parameter_dims(out, ...)
 }
 
 #' @rdname get_parameter_dims
 #' @export
 get_parameter_dims.dynamitefit <- function(x, ...) {
-  stopifnot_(
-    !is.null(x$stanfit),
-    "No Stan model fit is available."
-  )
   pars_text <- get_code(x, blocks = "parameters")
-  pars <- get_parameters(pars_text)
-  out <- rstan::get_inits(x$stanfit)[[1L]]
-  out <- out[names(out) %in% pars]
-  lapply(
-    out,
+  pars_text <- strsplit(pars_text, split = "\n")[[1L]]
+  pars_text <- pars_text[grepl(";", pars_text)]
+  par_regex <- regexec(
+    pattern = "^.+\\s([^\\s]+);.*$",
+    text = pars_text,
+    perl = TRUE
+  )
+  par_matches <- regmatches(pars_text, par_regex)
+  par_names <- vapply(par_matches, "[[", character(1L), 2L)
+  dim_regex <- regexec(
+    pattern = "^[^\\[]+\\[([^\\]]+)\\].+",
+    text = pars_text,
+    perl = TRUE
+  )
+  dim_matches <- regmatches(pars_text, dim_regex)
+  dim_names <- lapply(
+    dim_matches,
     function(y) {
-      d <- dim(y)
-      ifelse_(is.null(d), 1L, d)
+      if (length(y) > 0L) {
+        paste0("c(", y[2L], ")")
+      } else {
+        "1"
+      }
     }
   )
+  e <- list2env(get_data(x, ...))
+  stats::setNames(
+    lapply(
+      dim_names,
+      function(y) {
+        eval(str2lang(y), envir = e)
+      }
+    ),
+    par_names
+  )
 }
 
 #' Internal Parameter Block Variable Name Extraction
@@ -297,10 +304,10 @@ get_parameters <- function(x) {
   vapply(par_matches, "[[", character(1L), 2L)
 }
 
-#' Get Parameter Types of the Dynamite Model
+#' Get Parameter Types of the \pkg{dynamite} Model
 #'
 #' Extracts all parameter types of used in the `dynamitefit` object. See
-#' [dynamite::as.data.frame.dynamitefit()] for explanations of different types.
+#' [as.data.frame.dynamitefit()] for explanations of different types.
 #'
 #' @param x \[`dynamitefit`]\cr The model fit object.
 #' @param ... Ignored.
@@ -322,7 +329,7 @@ get_parameter_types.dynamitefit <- function(x, ...) {
   unique(d$type)
 }
 
-#' Get Parameter Names of the Dynamite Model
+#' Get Parameter Names of the \pkg{dynamite} Model
 #'
 #' Extracts all parameter names of used in the `dynamitefit` object.
 #'
@@ -335,7 +342,7 @@ get_parameter_types.dynamitefit <- function(x, ...) {
 #'
 #' @param x \[`dynamitefit`]\cr The model fit object.
 #' @param types \[`character()`]\cr Extract only names of parameter of a
-#'   certain type. See [dynamite::get_parameter_types()].
+#'   certain type. See [get_parameter_types()].
 #' @param ... Ignored.
 #' @return A `character` vector with parameter names of the input model.
 #' @export
