@@ -32,7 +32,7 @@ prepare_stan_input <- function(dformula, data, group_var, time_var,
     "Can't find variable{?s} {.var {resp[resp_missing]}} in {.arg data}."
   )
   specials <- lapply(dformula, evaluate_specials, data = data)
-  model_matrix <- full_model.matrix(dformula, data, verbose)
+  model_matrix <- full_model.matrix(dformula, data, group_var, fixed, verbose)
   cg <- attr(dformula, "channel_groups")
   n_cg <- n_unique(cg)
   n_channels <- length(resp_names)
@@ -68,7 +68,6 @@ prepare_stan_input <- function(dformula, data, group_var, time_var,
   time <- sort(unique(data[[time_var]]))
   T_full <- length(time)
   T_idx <- seq.int(fixed + 1L, T_full)
-  has_groups <- !is.null(group_var)
   group <- data[[group_var]]
   spline_def <- attr(dformula, "splines")
   random_def <- attr(dformula, "random_spec")
@@ -85,8 +84,7 @@ prepare_stan_input <- function(dformula, data, group_var, time_var,
   N <- n_unique(group)
   K <- ncol(model_matrix)
   X <- model_matrix[, ]
-  dim(X) <- c(T_full, N, K)
-  X <- X[T_idx, , , drop = FALSE]
+  dim(X) <- c(T_full - fixed, N, K)
   x_tmp <- X[1L, , , drop = FALSE]
   sd_x <- pmax(
     stats::setNames(apply(X, 3L, sd, na.rm = TRUE), colnames(model_matrix)),
@@ -98,7 +96,6 @@ prepare_stan_input <- function(dformula, data, group_var, time_var,
   X_na <- is.na(X)
   # Placeholder for NAs in Stan
   X[X_na] <- 0.0
-  assigned <- attr(model_matrix, "assign")
   fixed_pars <- attr(model_matrix, "fixed")
   varying_pars <- attr(model_matrix, "varying")
   random_pars <- attr(model_matrix, "random")
@@ -267,10 +264,10 @@ prepare_stan_input <- function(dformula, data, group_var, time_var,
   model_vars$P <- sampling_vars$P
   model_vars$D <- sampling_vars$D
   model_vars$K <- K
-  model_vars$common_priors = prior_list$common_priors
-  model_vars$spline_def = spline_def
-  model_vars$random_def = random_def
-  model_vars$lfactor_def = lfactor_def
+  model_vars$common_priors <- prior_list$common_priors
+  model_vars$spline_def <- spline_def
+  model_vars$random_def <- random_def
+  model_vars$lfactor_def <- lfactor_def
   list(
     channel_vars = channel_vars,
     channel_group_vars = channel_group_vars,
@@ -351,7 +348,7 @@ initialize_univariate_channel <- function(dformula, specials, fixed_pars,
   channel$has_fully_missing <- any(obs_len == 0L)
   sampling[[paste0("obs_", y_name)]] <- obs_idx
   sampling[[paste0("n_obs_", y_name)]] <- obs_len
-  sampling[[paste0("t_obs_", y_name)]] <- which(obs_len > 0L)
+  sampling[[paste0("t_obs_", y_name)]] <- as.array(which(obs_len > 0L))
   sampling[[paste0("T_obs_", y_name)]] <- length(which(obs_len > 0L))
   # obs selects complete cases if there are missing observations
   channel$obs <- ifelse_(
@@ -437,7 +434,9 @@ initialize_multivariate_channel <- function(y, y_cg, y_name, cg_idx,
   sampling[[paste0("n_obs_", y_cg)]] <- apply(
     sampling[[paste0("obs_", y_cg)]],
     2L,
-    function(x) { sum(x > 0L) }
+    function(x) {
+      sum(x > 0L)
+    }
   )
   sampling[[paste0("t_obs_", y_cg)]] <- which(
     sampling[[paste0("n_obs_", y_cg)]] > 0L
@@ -518,7 +517,7 @@ prepare_channel_default <- function(y, Y, channel, sampling,
       nzchar(category),
       priors[priors$response == y & priors$category == category, ],
       priors[priors$response == y, ]
-      )
+    )
     channel$prior_distr <- list()
     types <- priors$type
     loop_types <- intersect(
@@ -993,7 +992,7 @@ prepare_channel_multinomial <- function(y, y_cg, Y, channel, sampling,
     abort_factor(y_cg, "Multinomial", call = rlang::caller_env())
   }
   obs <- sampling[[paste0("n_obs_", y_cg)]] > 0L
-  Y_obs <- Y[obs, , ,drop = FALSE]
+  Y_obs <- Y[obs, , , drop = FALSE]
   if (any(Y_obs < 0.0) || any(Y_obs != as.integer(Y_obs))) {
     abort_negative(
       y_cg,
